@@ -6,10 +6,10 @@ from django.utils.translation import gettext_lazy as _
 
 
 class Email(models.Model):
-    create_date = models.DateTimeField(auto_now_add=True)
+    create_date = models.DateTimeField(auto_now_add=True, verbose_name=_("Creation date"))
     subject = models.TextField(blank=True, verbose_name=_("Subject"))
     body = models.TextField(blank=True, verbose_name=_('Body'))
-    content_subtype = models.CharField(max_length=254)
+    content_subtype = models.CharField(max_length=254, verbose_name=_("content subtype"))
     from_email = models.CharField(max_length=254, blank=True, verbose_name=_('From'))
     to = models.TextField(blank=True, verbose_name=_('To'))
     cc = models.TextField(blank=True, verbose_name=_('CC'))
@@ -21,6 +21,10 @@ class Email(models.Model):
     def __str__(self):
         return '{} - {}, {}'.format(self.subject, self.to, self.create_date)
 
+    class Meta:
+        verbose_name = _('Email Log')
+        verbose_name_plural = _('Emails Log')
+
 
 class EmailAlternative(models.Model):
     email = models.ForeignKey(Email, on_delete=models.CASCADE, related_name='alternatives')
